@@ -1,7 +1,10 @@
 import asyncio
 from aiohttp_requests import requests
-from kumihotools import toDomain
-import os
+import os, re
+
+def toDomain(url):
+    return re.sub(r'^https?://', '', url)
+
 
 async def get_sites(sem,url,foxhousePath): 
     async with sem:            
